@@ -17,6 +17,9 @@
 This module is not part of the public API surface.
 """
 
+# Avoid the grpc and google.cloud.grpc collision.
+from __future__ import absolute_import
+
 import calendar
 import datetime
 import json
@@ -38,10 +41,8 @@ import six
 from six.moves import http_client
 from six.moves import configparser
 
-# pylint: disable=ungrouped-imports
 from google.cloud.environment_vars import PROJECT
 from google.cloud.environment_vars import CREDENTIALS
-# pylint: enable=ungrouped-imports
 
 
 _NOW = datetime.datetime.utcnow  # To be replaced by tests.
@@ -52,8 +53,10 @@ _RFC3339_NANOS = re.compile(r"""
     (?P<no_fraction>
         \d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}  # YYYY-MM-DDTHH:MM:SS
     )
-    \.                                       # decimal point
-    (?P<nanos>\d{1,9})                       # nanoseconds, maybe truncated
+    (                                        # Optional decimal part
+     \.                                      # decimal point
+     (?P<nanos>\d{1,9})                      # nanoseconds, maybe truncated
+    )?
     Z                                        # Zulu
 """, re.VERBOSE)
 # NOTE: Catching this ImportError is a workaround for GAE not supporting the
@@ -242,7 +245,10 @@ def _default_service_project_id():
     config.read(search_paths)
 
     if config.has_section(_GCLOUD_CONFIG_SECTION):
-        return config.get(_GCLOUD_CONFIG_SECTION, _GCLOUD_CONFIG_KEY)
+        try:
+            return config.get(_GCLOUD_CONFIG_SECTION, _GCLOUD_CONFIG_KEY)
+        except configparser.NoOptionError:
+            return None
 
 
 def _compute_engine_id():
@@ -365,8 +371,8 @@ def _microseconds_from_datetime(value):
 def _millis_from_datetime(value):
     """Convert non-none datetime to timestamp, assuming UTC.
 
-    :type value: :class:`datetime.datetime`, or None
-    :param value: the timestamp
+    :type value: :class:`datetime.datetime`
+    :param value: (Optional) the timestamp
 
     :rtype: int, or ``NoneType``
     :returns: the timestamp, in milliseconds, or None
@@ -425,9 +431,12 @@ def _rfc3339_nanos_to_datetime(dt_str):
     bare_seconds = datetime.datetime.strptime(
         with_nanos.group('no_fraction'), _RFC3339_NO_FRACTION)
     fraction = with_nanos.group('nanos')
-    scale = 9 - len(fraction)
-    nanos = int(fraction) * (10 ** scale)
-    micros = nanos // 1000
+    if fraction is None:
+        micros = 0
+    else:
+        scale = 9 - len(fraction)
+        nanos = int(fraction) * (10 ** scale)
+        micros = nanos // 1000
     return bare_seconds.replace(microsecond=micros, tzinfo=UTC)
 
 
@@ -437,7 +446,7 @@ def _datetime_to_rfc3339(value, ignore_zone=True):
     :type value: :class:`datetime.datetime`
     :param value: The datetime object to be converted to a string.
 
-    :type ignore_zone: boolean
+    :type ignore_zone: bool
     :param ignore_zone: If True, then the timezone (if any) of the datetime
                         object is ignored.
 
@@ -525,7 +534,7 @@ def _pb_timestamp_to_rfc3339(timestamp_pb):
     :type timestamp_pb: :class:`google.protobuf.timestamp_pb2.Timestamp`
     :param timestamp_pb: A Google returned timestamp protobuf.
 
-    :rtype: string
+    :rtype: str
     :returns: An RFC 3339 formatted timestamp string.
     """
     timestamp = _pb_timestamp_to_datetime(timestamp_pb)
@@ -553,8 +562,8 @@ def _name_from_project_path(path, project, template):
     :type path: str
     :param path: URI path containing the name.
 
-    :type project: str or NoneType
-    :param project: The project associated with the request. It is
+    :type project: str
+    :param project: (Optional) The project associated with the request. It is
                     included for validation purposes.  If passed as None,
                     disables validation.
 
@@ -616,8 +625,8 @@ class MetadataPlugin(object):
         callback(headers, None)
 
 
-def make_secure_stub(credentials, user_agent, stub_class, host):
-    """Makes a secure stub for an RPC service.
+def make_secure_channel(credentials, user_agent, host):
+    """Makes a secure channel for an RPC service.
 
     Uses / depends on gRPC.
 
@@ -626,16 +635,13 @@ def make_secure_stub(credentials, user_agent, stub_class, host):
                         access tokens.
 
     :type user_agent: str
-    :param user_agent: (Optional) The user agent to be used with API requests.
-
-    :type stub_class: type
-    :param stub_class: A gRPC stub type for a given service.
+    :param user_agent: The user agent to be used with API requests.
 
     :type host: str
     :param host: The host for the service.
 
-    :rtype: object, instance of ``stub_class``
-    :returns: The stub object used to make gRPC requests to a given API.
+    :rtype: :class:`grpc._channel.Channel`
+    :returns: gRPC secure channel with credentials attached.
     """
     # ssl_channel_credentials() loads root certificates from
     # `grpc/_adapter/credentials/roots.pem`.
@@ -649,8 +655,32 @@ def make_secure_stub(credentials, user_agent, stub_class, host):
     channel_args = (
         ('grpc.primary_user_agent', user_agent),
     )
-    channel = grpc.secure_channel(target, channel_creds,
-                                  options=channel_args)
+    return grpc.secure_channel(target, channel_creds,
+                               options=channel_args)
+
+
+def make_secure_stub(credentials, user_agent, stub_class, host):
+    """Makes a secure stub for an RPC service.
+
+    Uses / depends on gRPC.
+
+    :type credentials: :class:`oauth2client.client.OAuth2Credentials`
+    :param credentials: The OAuth2 Credentials to use for creating
+                        access tokens.
+
+    :type user_agent: str
+    :param user_agent: The user agent to be used with API requests.
+
+    :type stub_class: type
+    :param stub_class: A gRPC stub type for a given service.
+
+    :type host: str
+    :param host: The host for the service.
+
+    :rtype: object, instance of ``stub_class``
+    :returns: The stub object used to make gRPC requests to a given API.
+    """
+    channel = make_secure_channel(credentials, user_agent, host)
     return stub_class(channel)
 
 
