@@ -18,7 +18,7 @@ from oauth2client.service_account import ServiceAccountCredentials
 import six
 
 from google.cloud._helpers import _determine_default_project
-from google.cloud.connection import Connection
+from google.cloud._http import Connection
 from google.cloud.credentials import get_credentials
 
 
@@ -34,7 +34,7 @@ class _ClientFactoryMixin(object):
     def from_service_account_json(cls, json_credentials_path, *args, **kwargs):
         """Factory to retrieve JSON credentials while creating client.
 
-        :type json_credentials_path: string
+        :type json_credentials_path: str
         :param json_credentials_path: The path to a private key file (this file
                                       was given to you when you created the
                                       service account). This file must contain
@@ -69,10 +69,10 @@ class _ClientFactoryMixin(object):
           Unless you have an explicit reason to use a PKCS12 key for your
           service account, we recommend using a JSON key.
 
-        :type client_email: string
+        :type client_email: str
         :param client_email: The e-mail attached to the service account.
 
-        :type private_key_path: string
+        :type private_key_path: str
         :param private_key_path: The path to a private key file (this file was
                                  given to you when you created the service
                                  account). This file must be in P12 format.
@@ -120,14 +120,14 @@ class Client(_ClientFactoryMixin):
     def __init__(self, credentials=None, http=None):
         if credentials is None and http is None:
             credentials = get_credentials()
-        self.connection = self._connection_class(
+        self._connection = self._connection_class(
             credentials=credentials, http=http)
 
 
 class _ClientProjectMixin(object):
     """Mixin to allow setting the project on the client.
 
-    :type project: string
+    :type project: str
     :param project: the project which the client acts on behalf of. If not
                     passed falls back to the default inferred from the
                     environment.
@@ -155,12 +155,12 @@ class _ClientProjectMixin(object):
 
 
 class JSONClient(Client, _ClientProjectMixin):
-    """Client to for Google JSON-based API.
+    """Client for Google JSON-based API.
 
     Assumes such APIs use the ``project`` and the client needs to store this
     value.
 
-    :type project: string
+    :type project: str
     :param project: the project which the client acts on behalf of. If not
                     passed falls back to the default inferred from the
                     environment.
