@@ -18,17 +18,18 @@ import unittest
 
 class Test__LocalStack(unittest.TestCase):
 
-    def _getTargetClass(self):
+    @staticmethod
+    def _get_target_class():
         from google.cloud._helpers import _LocalStack
 
         return _LocalStack
 
-    def _makeOne(self):
-        return self._getTargetClass()()
+    def _make_one(self):
+        return self._get_target_class()()
 
     def test_it(self):
         batch1, batch2 = object(), object()
-        batches = self._makeOne()
+        batches = self._make_one()
         self.assertEqual(list(batches), [])
         self.assertIsNone(batches.top)
         batches.push(batch1)
@@ -46,16 +47,17 @@ class Test__LocalStack(unittest.TestCase):
 
 class Test__UTC(unittest.TestCase):
 
-    def _getTargetClass(self):
+    @staticmethod
+    def _get_target_class():
         from google.cloud._helpers import _UTC
         return _UTC
 
-    def _makeOne(self):
-        return self._getTargetClass()()
+    def _make_one(self):
+        return self._get_target_class()()
 
     def test_module_property(self):
         from google.cloud import _helpers as MUT
-        klass = self._getTargetClass()
+        klass = self._get_target_class()
         try:
             import pytz
         except ImportError:
@@ -66,7 +68,7 @@ class Test__UTC(unittest.TestCase):
     def test_dst(self):
         import datetime
 
-        tz = self._makeOne()
+        tz = self._make_one()
         self.assertEqual(tz.dst(None), datetime.timedelta(0))
 
     def test_fromutc(self):
@@ -74,59 +76,59 @@ class Test__UTC(unittest.TestCase):
 
         naive_epoch = datetime.datetime.utcfromtimestamp(0)
         self.assertIsNone(naive_epoch.tzinfo)
-        tz = self._makeOne()
+        tz = self._make_one()
         epoch = tz.fromutc(naive_epoch)
         self.assertEqual(epoch.tzinfo, tz)
 
     def test_tzname(self):
-        tz = self._makeOne()
+        tz = self._make_one()
         self.assertEqual(tz.tzname(None), 'UTC')
 
     def test_utcoffset(self):
         import datetime
 
-        tz = self._makeOne()
+        tz = self._make_one()
         self.assertEqual(tz.utcoffset(None), datetime.timedelta(0))
 
     def test___repr__(self):
-        tz = self._makeOne()
+        tz = self._make_one()
         self.assertEqual(repr(tz), '<UTC>')
 
     def test___str__(self):
-        tz = self._makeOne()
+        tz = self._make_one()
         self.assertEqual(str(tz), 'UTC')
 
 
 class Test__ensure_tuple_or_list(unittest.TestCase):
 
-    def _callFUT(self, arg_name, tuple_or_list):
+    def _call_fut(self, arg_name, tuple_or_list):
         from google.cloud._helpers import _ensure_tuple_or_list
         return _ensure_tuple_or_list(arg_name, tuple_or_list)
 
     def test_valid_tuple(self):
         valid_tuple_or_list = ('a', 'b', 'c', 'd')
-        result = self._callFUT('ARGNAME', valid_tuple_or_list)
+        result = self._call_fut('ARGNAME', valid_tuple_or_list)
         self.assertEqual(result, ['a', 'b', 'c', 'd'])
 
     def test_valid_list(self):
         valid_tuple_or_list = ['a', 'b', 'c', 'd']
-        result = self._callFUT('ARGNAME', valid_tuple_or_list)
+        result = self._call_fut('ARGNAME', valid_tuple_or_list)
         self.assertEqual(result, valid_tuple_or_list)
 
     def test_invalid(self):
         invalid_tuple_or_list = object()
         with self.assertRaises(TypeError):
-            self._callFUT('ARGNAME', invalid_tuple_or_list)
+            self._call_fut('ARGNAME', invalid_tuple_or_list)
 
     def test_invalid_iterable(self):
         invalid_tuple_or_list = 'FOO'
         with self.assertRaises(TypeError):
-            self._callFUT('ARGNAME', invalid_tuple_or_list)
+            self._call_fut('ARGNAME', invalid_tuple_or_list)
 
 
 class Test__app_engine_id(unittest.TestCase):
 
-    def _callFUT(self):
+    def _call_fut(self):
         from google.cloud._helpers import _app_engine_id
         return _app_engine_id()
 
@@ -135,7 +137,7 @@ class Test__app_engine_id(unittest.TestCase):
         from google.cloud import _helpers
 
         with _Monkey(_helpers, app_identity=None):
-            dataset_id = self._callFUT()
+            dataset_id = self._call_fut()
             self.assertIsNone(dataset_id)
 
     def test_value_set(self):
@@ -145,13 +147,13 @@ class Test__app_engine_id(unittest.TestCase):
         APP_ENGINE_ID = object()
         APP_IDENTITY = _AppIdentity(APP_ENGINE_ID)
         with _Monkey(_helpers, app_identity=APP_IDENTITY):
-            dataset_id = self._callFUT()
+            dataset_id = self._call_fut()
             self.assertEqual(dataset_id, APP_ENGINE_ID)
 
 
 class Test__file_project_id(unittest.TestCase):
 
-    def _callFUT(self):
+    def _call_fut(self):
         from google.cloud._helpers import _file_project_id
         return _file_project_id()
 
@@ -168,7 +170,7 @@ class Test__file_project_id(unittest.TestCase):
 
             environ = {CREDENTIALS: temp.name}
             with _Monkey(os, getenv=environ.get):
-                result = self._callFUT()
+                result = self._call_fut()
 
             self.assertEqual(result, project_id)
 
@@ -177,14 +179,14 @@ class Test__file_project_id(unittest.TestCase):
 
         environ = {}
         with _Monkey(os, getenv=environ.get):
-            result = self._callFUT()
+            result = self._call_fut()
 
         self.assertIsNone(result)
 
 
 class Test__get_nix_config_path(unittest.TestCase):
 
-    def _callFUT(self):
+    def _call_fut(self):
         from google.cloud._helpers import _get_nix_config_path
         return _get_nix_config_path()
 
@@ -196,7 +198,7 @@ class Test__get_nix_config_path(unittest.TestCase):
         config_file = 'b'
         with _Monkey(MUT, _USER_ROOT=user_root,
                      _GCLOUD_CONFIG_FILE=config_file):
-            result = self._callFUT()
+            result = self._call_fut()
 
         expected = os.path.join(user_root, '.config', config_file)
         self.assertEqual(result, expected)
@@ -204,7 +206,7 @@ class Test__get_nix_config_path(unittest.TestCase):
 
 class Test__get_windows_config_path(unittest.TestCase):
 
-    def _callFUT(self):
+    def _call_fut(self):
         from google.cloud._helpers import _get_windows_config_path
         return _get_windows_config_path()
 
@@ -217,7 +219,7 @@ class Test__get_windows_config_path(unittest.TestCase):
         config_file = 'b'
         with _Monkey(os, getenv=environ.get):
             with _Monkey(MUT, _GCLOUD_CONFIG_FILE=config_file):
-                result = self._callFUT()
+                result = self._call_fut()
 
         expected = os.path.join(appdata_dir, config_file)
         self.assertEqual(result, expected)
@@ -227,7 +229,7 @@ class Test__default_service_project_id(unittest.TestCase):
 
     CONFIG_TEMPLATE = '[%s]\n%s = %s\n'
 
-    def _callFUT(self):
+    def _call_fut(self):
         from google.cloud._helpers import _default_service_project_id
         return _default_service_project_id()
 
@@ -250,10 +252,30 @@ class Test__default_service_project_id(unittest.TestCase):
             with _Monkey(os, name='not-nt'):
                 with _Monkey(MUT, _get_nix_config_path=mock_get_path,
                              _USER_ROOT='not-None'):
-                    result = self._callFUT()
+                    result = self._call_fut()
 
             self.assertEqual(result, project_id)
 
+    def test_nix_missing_prject_key(self):
+        from google.cloud import _helpers as MUT
+        from google.cloud._testing import _Monkey
+        from google.cloud._testing import _NamedTemporaryFile
+
+        with _NamedTemporaryFile() as temp:
+            config_value = '[%s]' % (MUT._GCLOUD_CONFIG_SECTION,)
+            with open(temp.name, 'w') as config_file:
+                config_file.write(config_value)
+
+            def mock_get_path():
+                return temp.name
+
+            with _Monkey(os, name='not-nt'):
+                with _Monkey(MUT, _get_nix_config_path=mock_get_path,
+                             _USER_ROOT='not-None'):
+                    result = self._call_fut()
+
+            self.assertEqual(result, None)
+
     def test_windows(self):
         from google.cloud import _helpers as MUT
         from google.cloud._testing import _Monkey
@@ -273,7 +295,7 @@ class Test__default_service_project_id(unittest.TestCase):
             with _Monkey(os, name='nt'):
                 with _Monkey(MUT, _get_windows_config_path=mock_get_path,
                              _USER_ROOT=None):
-                    result = self._callFUT()
+                    result = self._call_fut()
 
             self.assertEqual(result, project_id)
 
@@ -283,14 +305,14 @@ class Test__default_service_project_id(unittest.TestCase):
 
         with _Monkey(os, name='not-nt'):
             with _Monkey(MUT, _USER_ROOT=None):
-                result = self._callFUT()
+                result = self._call_fut()
 
         self.assertIsNone(result)
 
 
 class Test__compute_engine_id(unittest.TestCase):
 
-    def _callFUT(self):
+    def _call_fut(self):
         from google.cloud._helpers import _compute_engine_id
         return _compute_engine_id()
 
@@ -308,26 +330,26 @@ class Test__compute_engine_id(unittest.TestCase):
     def test_bad_status(self):
         connection = _HTTPConnection(404, None)
         with self._monkeyConnection(connection):
-            dataset_id = self._callFUT()
+            dataset_id = self._call_fut()
             self.assertIsNone(dataset_id)
 
     def test_success(self):
         COMPUTE_ENGINE_ID = object()
         connection = _HTTPConnection(200, COMPUTE_ENGINE_ID)
         with self._monkeyConnection(connection):
-            dataset_id = self._callFUT()
+            dataset_id = self._call_fut()
             self.assertEqual(dataset_id, COMPUTE_ENGINE_ID)
 
     def test_socket_raises(self):
         connection = _TimeoutHTTPConnection()
         with self._monkeyConnection(connection):
-            dataset_id = self._callFUT()
+            dataset_id = self._call_fut()
             self.assertIsNone(dataset_id)
 
 
 class Test__get_production_project(unittest.TestCase):
 
-    def _callFUT(self):
+    def _call_fut(self):
         from google.cloud._helpers import _get_production_project
         return _get_production_project()
 
@@ -336,7 +358,7 @@ class Test__get_production_project(unittest.TestCase):
 
         environ = {}
         with _Monkey(os, getenv=environ.get):
-            project = self._callFUT()
+            project = self._call_fut()
             self.assertIsNone(project)
 
     def test_value_set(self):
@@ -346,13 +368,13 @@ class Test__get_production_project(unittest.TestCase):
         MOCK_PROJECT = object()
         environ = {PROJECT: MOCK_PROJECT}
         with _Monkey(os, getenv=environ.get):
-            project = self._callFUT()
+            project = self._call_fut()
             self.assertEqual(project, MOCK_PROJECT)
 
 
 class Test__determine_default_project(unittest.TestCase):
 
-    def _callFUT(self, project=None):
+    def _call_fut(self, project=None):
         from google.cloud._helpers import _determine_default_project
         return _determine_default_project(project=project)
 
@@ -392,7 +414,7 @@ class Test__determine_default_project(unittest.TestCase):
         }
 
         with _Monkey(_helpers, **patched_methods):
-            returned_project = self._callFUT(project)
+            returned_project = self._call_fut(project)
 
         return returned_project, _callers
 
@@ -431,7 +453,7 @@ class Test__determine_default_project(unittest.TestCase):
 
 class Test__millis(unittest.TestCase):
 
-    def _callFUT(self, value):
+    def _call_fut(self, value):
         from google.cloud._helpers import _millis
         return _millis(value)
 
@@ -440,12 +462,12 @@ class Test__millis(unittest.TestCase):
         from google.cloud._helpers import UTC
 
         WHEN = datetime.datetime(1970, 1, 1, 0, 0, 1, tzinfo=UTC)
-        self.assertEqual(self._callFUT(WHEN), 1000)
+        self.assertEqual(self._call_fut(WHEN), 1000)
 
 
 class Test__microseconds_from_datetime(unittest.TestCase):
 
-    def _callFUT(self, value):
+    def _call_fut(self, value):
         from google.cloud._helpers import _microseconds_from_datetime
         return _microseconds_from_datetime(value)
 
@@ -456,18 +478,18 @@ class Test__microseconds_from_datetime(unittest.TestCase):
         timestamp = datetime.datetime(1970, 1, 1, hour=0,
                                       minute=0, second=0,
                                       microsecond=microseconds)
-        result = self._callFUT(timestamp)
+        result = self._call_fut(timestamp)
         self.assertEqual(result, microseconds)
 
 
 class Test__millis_from_datetime(unittest.TestCase):
 
-    def _callFUT(self, value):
+    def _call_fut(self, value):
         from google.cloud._helpers import _millis_from_datetime
         return _millis_from_datetime(value)
 
     def test_w_none(self):
-        self.assertIsNone(self._callFUT(None))
+        self.assertIsNone(self._call_fut(None))
 
     def test_w_utc_datetime(self):
         import datetime
@@ -478,7 +500,7 @@ class Test__millis_from_datetime(unittest.TestCase):
         NOW = datetime.datetime.utcnow().replace(tzinfo=UTC)
         NOW_MICROS = _microseconds_from_datetime(NOW)
         MILLIS = NOW_MICROS // 1000
-        result = self._callFUT(NOW)
+        result = self._call_fut(NOW)
         self.assertIsInstance(result, six.integer_types)
         self.assertEqual(result, MILLIS)
 
@@ -496,7 +518,7 @@ class Test__millis_from_datetime(unittest.TestCase):
         NOW = datetime.datetime(2015, 7, 28, 16, 34, 47, tzinfo=zone)
         NOW_MICROS = _microseconds_from_datetime(NOW)
         MILLIS = NOW_MICROS // 1000
-        result = self._callFUT(NOW)
+        result = self._call_fut(NOW)
         self.assertIsInstance(result, six.integer_types)
         self.assertEqual(result, MILLIS)
 
@@ -510,14 +532,14 @@ class Test__millis_from_datetime(unittest.TestCase):
         UTC_NOW = NOW.replace(tzinfo=UTC)
         UTC_NOW_MICROS = _microseconds_from_datetime(UTC_NOW)
         MILLIS = UTC_NOW_MICROS // 1000
-        result = self._callFUT(NOW)
+        result = self._call_fut(NOW)
         self.assertIsInstance(result, six.integer_types)
         self.assertEqual(result, MILLIS)
 
 
 class Test__datetime_from_microseconds(unittest.TestCase):
 
-    def _callFUT(self, value):
+    def _call_fut(self, value):
         from google.cloud._helpers import _datetime_from_microseconds
         return _datetime_from_microseconds(value)
 
@@ -529,24 +551,24 @@ class Test__datetime_from_microseconds(unittest.TestCase):
         NOW = datetime.datetime(2015, 7, 29, 17, 45, 21, 123456,
                                 tzinfo=UTC)
         NOW_MICROS = _microseconds_from_datetime(NOW)
-        self.assertEqual(self._callFUT(NOW_MICROS), NOW)
+        self.assertEqual(self._call_fut(NOW_MICROS), NOW)
 
 
 class Test___date_from_iso8601_date(unittest.TestCase):
 
-    def _callFUT(self, value):
+    def _call_fut(self, value):
         from google.cloud._helpers import _date_from_iso8601_date
         return _date_from_iso8601_date(value)
 
     def test_todays_date(self):
         import datetime
         TODAY = datetime.date.today()
-        self.assertEqual(self._callFUT(TODAY.strftime("%Y-%m-%d")), TODAY)
+        self.assertEqual(self._call_fut(TODAY.strftime("%Y-%m-%d")), TODAY)
 
 
 class Test__rfc3339_to_datetime(unittest.TestCase):
 
-    def _callFUT(self, dt_str):
+    def _call_fut(self, dt_str):
         from google.cloud._helpers import _rfc3339_to_datetime
         return _rfc3339_to_datetime(dt_str)
 
@@ -562,7 +584,7 @@ class Test__rfc3339_to_datetime(unittest.TestCase):
         dt_str = '%d-%02d-%02dT%02d:%02d:%02d.%06dBOGUS' % (
             year, month, day, hour, minute, seconds, micros)
         with self.assertRaises(ValueError):
-            self._callFUT(dt_str)
+            self._call_fut(dt_str)
 
     def test_w_microseconds(self):
         import datetime
@@ -578,7 +600,7 @@ class Test__rfc3339_to_datetime(unittest.TestCase):
 
         dt_str = '%d-%02d-%02dT%02d:%02d:%02d.%06dZ' % (
             year, month, day, hour, minute, seconds, micros)
-        result = self._callFUT(dt_str)
+        result = self._call_fut(dt_str)
         expected_result = datetime.datetime(
             year, month, day, hour, minute, seconds, micros, UTC)
         self.assertEqual(result, expected_result)
@@ -595,12 +617,12 @@ class Test__rfc3339_to_datetime(unittest.TestCase):
         dt_str = '%d-%02d-%02dT%02d:%02d:%02d.%09dZ' % (
             year, month, day, hour, minute, seconds, nanos)
         with self.assertRaises(ValueError):
-            self._callFUT(dt_str)
+            self._call_fut(dt_str)
 
 
 class Test__rfc3339_nanos_to_datetime(unittest.TestCase):
 
-    def _callFUT(self, dt_str):
+    def _call_fut(self, dt_str):
         from google.cloud._helpers import _rfc3339_nanos_to_datetime
         return _rfc3339_nanos_to_datetime(dt_str)
 
@@ -616,7 +638,7 @@ class Test__rfc3339_nanos_to_datetime(unittest.TestCase):
         dt_str = '%d-%02d-%02dT%02d:%02d:%02d.%06dBOGUS' % (
             year, month, day, hour, minute, seconds, micros)
         with self.assertRaises(ValueError):
-            self._callFUT(dt_str)
+            self._call_fut(dt_str)
 
     def test_w_truncated_nanos(self):
         import datetime
@@ -642,11 +664,29 @@ class Test__rfc3339_nanos_to_datetime(unittest.TestCase):
         for truncated, micros in truncateds_and_micros:
             dt_str = '%d-%02d-%02dT%02d:%02d:%02d.%sZ' % (
                 year, month, day, hour, minute, seconds, truncated)
-            result = self._callFUT(dt_str)
+            result = self._call_fut(dt_str)
             expected_result = datetime.datetime(
                 year, month, day, hour, minute, seconds, micros, UTC)
             self.assertEqual(result, expected_result)
 
+    def test_without_nanos(self):
+        import datetime
+        from google.cloud._helpers import UTC
+
+        year = 1988
+        month = 4
+        day = 29
+        hour = 12
+        minute = 12
+        seconds = 12
+
+        dt_str = '%d-%02d-%02dT%02d:%02d:%02dZ' % (
+            year, month, day, hour, minute, seconds)
+        result = self._call_fut(dt_str)
+        expected_result = datetime.datetime(
+            year, month, day, hour, minute, seconds, 0, UTC)
+        self.assertEqual(result, expected_result)
+
     def test_w_naonseconds(self):
         import datetime
         from google.cloud._helpers import UTC
@@ -662,7 +702,7 @@ class Test__rfc3339_nanos_to_datetime(unittest.TestCase):
 
         dt_str = '%d-%02d-%02dT%02d:%02d:%02d.%09dZ' % (
             year, month, day, hour, minute, seconds, nanos)
-        result = self._callFUT(dt_str)
+        result = self._call_fut(dt_str)
         expected_result = datetime.datetime(
             year, month, day, hour, minute, seconds, micros, UTC)
         self.assertEqual(result, expected_result)
@@ -670,7 +710,7 @@ class Test__rfc3339_nanos_to_datetime(unittest.TestCase):
 
 class Test__datetime_to_rfc3339(unittest.TestCase):
 
-    def _callFUT(self, *args, **kwargs):
+    def _call_fut(self, *args, **kwargs):
         from google.cloud._helpers import _datetime_to_rfc3339
         return _datetime_to_rfc3339(*args, **kwargs)
 
@@ -689,86 +729,84 @@ class Test__datetime_to_rfc3339(unittest.TestCase):
         from google.cloud._helpers import UTC
 
         TIMESTAMP = datetime.datetime(2016, 4, 5, 13, 30, 0, tzinfo=UTC)
-        result = self._callFUT(TIMESTAMP, ignore_zone=False)
+        result = self._call_fut(TIMESTAMP, ignore_zone=False)
         self.assertEqual(result, '2016-04-05T13:30:00.000000Z')
 
     def test_w_non_utc_datetime(self):
         import datetime
-        from google.cloud._helpers import _UTC
 
         zone = self._make_timezone(offset=datetime.timedelta(hours=-1))
         TIMESTAMP = datetime.datetime(2016, 4, 5, 13, 30, 0, tzinfo=zone)
-        result = self._callFUT(TIMESTAMP, ignore_zone=False)
+        result = self._call_fut(TIMESTAMP, ignore_zone=False)
         self.assertEqual(result, '2016-04-05T14:30:00.000000Z')
 
     def test_w_non_utc_datetime_and_ignore_zone(self):
         import datetime
-        from google.cloud._helpers import _UTC
 
         zone = self._make_timezone(offset=datetime.timedelta(hours=-1))
         TIMESTAMP = datetime.datetime(2016, 4, 5, 13, 30, 0, tzinfo=zone)
-        result = self._callFUT(TIMESTAMP)
+        result = self._call_fut(TIMESTAMP)
         self.assertEqual(result, '2016-04-05T13:30:00.000000Z')
 
     def test_w_naive_datetime(self):
         import datetime
 
         TIMESTAMP = datetime.datetime(2016, 4, 5, 13, 30, 0)
-        result = self._callFUT(TIMESTAMP)
+        result = self._call_fut(TIMESTAMP)
         self.assertEqual(result, '2016-04-05T13:30:00.000000Z')
 
 
 class Test__to_bytes(unittest.TestCase):
 
-    def _callFUT(self, *args, **kwargs):
+    def _call_fut(self, *args, **kwargs):
         from google.cloud._helpers import _to_bytes
         return _to_bytes(*args, **kwargs)
 
     def test_with_bytes(self):
         value = b'bytes-val'
-        self.assertEqual(self._callFUT(value), value)
+        self.assertEqual(self._call_fut(value), value)
 
     def test_with_unicode(self):
         value = u'string-val'
         encoded_value = b'string-val'
-        self.assertEqual(self._callFUT(value), encoded_value)
+        self.assertEqual(self._call_fut(value), encoded_value)
 
     def test_unicode_non_ascii(self):
         value = u'\u2013'  # Long hyphen
         encoded_value = b'\xe2\x80\x93'
-        self.assertRaises(UnicodeEncodeError, self._callFUT, value)
-        self.assertEqual(self._callFUT(value, encoding='utf-8'),
+        self.assertRaises(UnicodeEncodeError, self._call_fut, value)
+        self.assertEqual(self._call_fut(value, encoding='utf-8'),
                          encoded_value)
 
     def test_with_nonstring_type(self):
         value = object()
-        self.assertRaises(TypeError, self._callFUT, value)
+        self.assertRaises(TypeError, self._call_fut, value)
 
 
 class Test__bytes_to_unicode(unittest.TestCase):
 
-    def _callFUT(self, *args, **kwargs):
+    def _call_fut(self, *args, **kwargs):
         from google.cloud._helpers import _bytes_to_unicode
         return _bytes_to_unicode(*args, **kwargs)
 
     def test_with_bytes(self):
         value = b'bytes-val'
         encoded_value = 'bytes-val'
-        self.assertEqual(self._callFUT(value), encoded_value)
+        self.assertEqual(self._call_fut(value), encoded_value)
 
     def test_with_unicode(self):
         value = u'string-val'
         encoded_value = 'string-val'
-        self.assertEqual(self._callFUT(value), encoded_value)
+        self.assertEqual(self._call_fut(value), encoded_value)
 
     def test_with_nonstring_type(self):
         value = object()
-        self.assertRaises(ValueError, self._callFUT, value)
+        self.assertRaises(ValueError, self._call_fut, value)
 
 
 class Test__pb_timestamp_to_datetime(unittest.TestCase):
 
-    def _callFUT(self, timestamp):
+    def _call_fut(self, timestamp):
         from google.cloud._helpers import _pb_timestamp_to_datetime
         return _pb_timestamp_to_datetime(timestamp)
 
@@ -784,12 +822,12 @@ class Test__pb_timestamp_to_datetime(unittest.TestCase):
         # ... so 1 minute and 1 second after is 61 seconds and 1234
         # microseconds is 1234000 nanoseconds.
         timestamp = Timestamp(seconds=61, nanos=1234000)
-        self.assertEqual(self._callFUT(timestamp), dt_stamp)
+        self.assertEqual(self._call_fut(timestamp), dt_stamp)
 
 
 class Test__pb_timestamp_to_rfc3339(unittest.TestCase):
 
-    def _callFUT(self, timestamp):
+    def _call_fut(self, timestamp):
         from google.cloud._helpers import _pb_timestamp_to_rfc3339
         return _pb_timestamp_to_rfc3339(timestamp)
 
@@ -800,13 +838,13 @@ class Test__pb_timestamp_to_rfc3339(unittest.TestCase):
         # ... so 1 minute and 1 second after is 61 seconds and 1234
         # microseconds is 1234000 nanoseconds.
         timestamp = Timestamp(seconds=61, nanos=1234000)
-        self.assertEqual(self._callFUT(timestamp),
+        self.assertEqual(self._call_fut(timestamp),
                          '1970-01-01T00:01:01.001234Z')
 
 
 class Test__datetime_to_pb_timestamp(unittest.TestCase):
 
-    def _callFUT(self, when):
+    def _call_fut(self, when):
         from google.cloud._helpers import _datetime_to_pb_timestamp
         return _datetime_to_pb_timestamp(when)
 
@@ -822,7 +860,7 @@ class Test__datetime_to_pb_timestamp(unittest.TestCase):
         # ... so 1 minute and 1 second after is 61 seconds and 1234
         # microseconds is 1234000 nanoseconds.
         timestamp = Timestamp(seconds=61, nanos=1234000)
-        self.assertEqual(self._callFUT(dt_stamp), timestamp)
+        self.assertEqual(self._call_fut(dt_stamp), timestamp)
 
 
 class Test__name_from_project_path(unittest.TestCase):
@@ -831,54 +869,55 @@ class Test__name_from_project_path(unittest.TestCase):
     THING_NAME = 'THING_NAME'
     TEMPLATE = r'projects/(?P<project>\w+)/things/(?P<name>\w+)'
 
-    def _callFUT(self, path, project, template):
+    def _call_fut(self, path, project, template):
         from google.cloud._helpers import _name_from_project_path
         return _name_from_project_path(path, project, template)
 
     def test_w_invalid_path_length(self):
         PATH = 'projects/foo'
         with self.assertRaises(ValueError):
-            self._callFUT(PATH, None, self.TEMPLATE)
+            self._call_fut(PATH, None, self.TEMPLATE)
 
     def test_w_invalid_path_segments(self):
         PATH = 'foo/%s/bar/%s' % (self.PROJECT, self.THING_NAME)
         with self.assertRaises(ValueError):
-            self._callFUT(PATH, self.PROJECT, self.TEMPLATE)
+            self._call_fut(PATH, self.PROJECT, self.TEMPLATE)
 
     def test_w_mismatched_project(self):
         PROJECT1 = 'PROJECT1'
         PROJECT2 = 'PROJECT2'
         PATH = 'projects/%s/things/%s' % (PROJECT1, self.THING_NAME)
         with self.assertRaises(ValueError):
-            self._callFUT(PATH, PROJECT2, self.TEMPLATE)
+            self._call_fut(PATH, PROJECT2, self.TEMPLATE)
 
     def test_w_valid_data_w_compiled_regex(self):
         import re
         template = re.compile(self.TEMPLATE)
         PATH = 'projects/%s/things/%s' % (self.PROJECT, self.THING_NAME)
-        name = self._callFUT(PATH, self.PROJECT, template)
+        name = self._call_fut(PATH, self.PROJECT, template)
         self.assertEqual(name, self.THING_NAME)
 
     def test_w_project_passed_as_none(self):
         PROJECT1 = 'PROJECT1'
         PATH = 'projects/%s/things/%s' % (PROJECT1, self.THING_NAME)
-        self._callFUT(PATH, None, self.TEMPLATE)
-        name = self._callFUT(PATH, None, self.TEMPLATE)
+        self._call_fut(PATH, None, self.TEMPLATE)
+        name = self._call_fut(PATH, None, self.TEMPLATE)
         self.assertEqual(name, self.THING_NAME)
 
 
 class TestMetadataPlugin(unittest.TestCase):
 
-    def _getTargetClass(self):
+    @staticmethod
+    def _get_target_class():
         from google.cloud._helpers import MetadataPlugin
         return MetadataPlugin
 
-    def _makeOne(self, *args, **kwargs):
-        return self._getTargetClass()(*args, **kwargs)
+    def _make_one(self, *args, **kwargs):
+        return self._get_target_class()(*args, **kwargs)
 
     def test_constructor(self):
         credentials = object()
-        plugin = self._makeOne(credentials)
+        plugin = self._make_one(credentials)
         self.assertIs(plugin._credentials, credentials)
 
     def test___call__(self):
@@ -889,7 +928,7 @@ class TestMetadataPlugin(unittest.TestCase):
         def callback(*args):
             callback_args.append(args)
 
-        transformer = self._makeOne(credentials)
+        transformer = self._make_one(credentials)
         result = transformer(None, callback)
         cb_headers = [
             ('authorization', 'Bearer ' + access_token_expected),
@@ -899,20 +938,17 @@ class TestMetadataPlugin(unittest.TestCase):
         self.assertEqual(len(credentials._tokens), 1)
 
 
-class Test_make_secure_stub(unittest.TestCase):
+class Test_make_secure_channel(unittest.TestCase):
 
-    def _callFUT(self, *args, **kwargs):
-        from google.cloud._helpers import make_secure_stub
-        return make_secure_stub(*args, **kwargs)
+    def _call_fut(self, *args, **kwargs):
+        from google.cloud._helpers import make_secure_channel
+        return make_secure_channel(*args, **kwargs)
 
     def test_it(self):
         from six.moves import http_client
         from google.cloud._testing import _Monkey
         from google.cloud import _helpers as MUT
 
-        mock_result = object()
-        stub_inputs = []
-
         SSL_CREDS = object()
         METADATA_CREDS = object()
         COMPOSITE_CREDS = object()
@@ -943,11 +979,6 @@ class Test_make_secure_stub(unittest.TestCase):
                 return CHANNEL
 
         grpc_mod = _GRPCModule()
-
-        def mock_stub_class(channel):
-            stub_inputs.append(channel)
-            return mock_result
-
         metadata_plugin = object()
         plugin_args = []
 
@@ -960,11 +991,9 @@ class Test_make_secure_stub(unittest.TestCase):
         user_agent = 'USER_AGENT'
         with _Monkey(MUT, grpc=grpc_mod,
                      MetadataPlugin=mock_plugin):
-            result = self._callFUT(credentials, user_agent,
-                                   mock_stub_class, host)
+            result = self._call_fut(credentials, user_agent, host)
 
-        self.assertIs(result, mock_result)
-        self.assertEqual(stub_inputs, [CHANNEL])
+        self.assertIs(result, CHANNEL)
         self.assertEqual(plugin_args, [(credentials,)])
         self.assertEqual(grpc_mod.ssl_channel_credentials_args, ())
         self.assertEqual(grpc_mod.metadata_call_credentials_args,
@@ -981,9 +1010,45 @@ class Test_make_secure_stub(unittest.TestCase):
                          (secure_args, secure_kwargs))
 
 
+class Test_make_secure_stub(unittest.TestCase):
+
+    def _call_fut(self, *args, **kwargs):
+        from google.cloud._helpers import make_secure_stub
+        return make_secure_stub(*args, **kwargs)
+
+    def test_it(self):
+        from google.cloud._testing import _Monkey
+        from google.cloud import _helpers as MUT
+
+        result = object()
+        channel_obj = object()
+        channels = []
+        channel_args = []
+
+        def stub_class(channel):
+            channels.append(channel)
+            return result
+
+        def mock_channel(*args):
+            channel_args.append(args)
+            return channel_obj
+
+        credentials = object()
+        user_agent = 'you-sir-age-int'
+        host = 'localhost'
+        with _Monkey(MUT, make_secure_channel=mock_channel):
+            stub = self._call_fut(credentials, user_agent,
+                                  stub_class, host)
+
+        self.assertIs(stub, result)
+        self.assertEqual(channels, [channel_obj])
+        self.assertEqual(channel_args,
+                         [(credentials, user_agent, host)])
+
+
 class Test_make_insecure_stub(unittest.TestCase):
 
-    def _callFUT(self, *args, **kwargs):
+    def _call_fut(self, *args, **kwargs):
         from google.cloud._helpers import make_insecure_stub
         return make_insecure_stub(*args, **kwargs)
 
@@ -1008,7 +1073,7 @@ class Test_make_insecure_stub(unittest.TestCase):
             return mock_result
 
         with _Monkey(MUT, grpc=grpc_mod):
-            result = self._callFUT(mock_stub_class, host, port=port)
+            result = self._call_fut(mock_stub_class, host, port=port)
 
         self.assertIs(result, mock_result)
         self.assertEqual(stub_inputs, [CHANNEL])
